@@ -27,7 +27,7 @@ def find_nearby_projects(project_name, dist=10, print_data=True, include_retired
             Defaults to `df_keys` if no `df` supplied.
 
     Returns:
-        DataFrame: Contains information about all sites within the specified\
+        nearby_sites (DataFrame): Contains information about all sites within the specified\
         distance from the reference site.
     """
     # Set `df` to `df_keys` if not supplied
